@@ -12,6 +12,8 @@ from functools import partial
 from .. import core
 from ..consts import CONFIG
 from ..consts import RAPPORT_HTML
+from ..consts import REST_CLIENT
+from ..consts import FUPDB_CREDENTIALS
 from ..customer import Customer
 from ..product import Product
 from ..product_gp import Product_GP
@@ -20,6 +22,7 @@ from . import app
 import click
 import smtplib
 import tablib
+import records
 
 
 @click.group()
@@ -67,6 +70,80 @@ def notify():
             click.echo(msg)
 
 
+@cmd.command()
+def reconciled():
+    """compare les clients fupe dans aiguillier et api-fup"""
+    click.echo('recupère clients fupé sur aiguillier')
+    dataset_reconcile = tablib.Dataset()
+    message = ''
+    customers = []
+    dataset_reconcile.headers = [
+        'customers',
+        'fup_aiguillier',
+        'fup_api'
+        ]
+
+    response = REST_CLIENT.get(
+        '/fup',
+        auth=(
+            CONFIG['AIGUILLIER']['username'],
+            CONFIG['AIGUILLIER']['password']
+            )
+        )
+    infos = response['content']['fup']
+    infos_aiguillier = [
+                            info['name'].lower()
+                            for info in infos
+                            if info['name']
+                            ]
+    click.echo('verifie si clients fupé dans api-fup')
+    url = core.database_url(**FUPDB_CREDENTIALS)
+    with records.Database(url) as db:
+        sql = (
+            "SELECT * FROM fup AS data "
+            "WHERE datetime = "
+            "(SELECT MAX(datetime) FROM fup "
+            "WHERE customer = data.customer) "
+            "and status = True"
+            )
+        rows = db.query(sql)
+        infos_api = [row.customer for row in rows]
+    customers = [x for x in infos_aiguillier if x not in customers]
+    for info in infos_api:
+        if info not in customers:
+            customers.append(info)
+    for customer in customers:
+        result_aiguillier = 'NO'
+        result_api = 'NO'
+        if customer in infos_aiguillier:
+            result_aiguillier = 'YES'
+        if customer in infos_api:
+            result_api = 'YES'
+        dataset_reconcile.append(
+            [
+                customer,
+                result_aiguillier,
+                result_api
+                ]
+            )
+    message += str(dataset_reconcile)
+    # envoyer msg
+    email = CONFIG['ALERT']['to_1']
+    content = MIMEText(message, 'plain', 'utf-8')
+    msg = MIMEMultipart()
+    msg['Subject'] = '[blueline] Reconcile FUP'
+    msg['From'] = CONFIG['ALERT']['from']
+    msg['To'] = email
+    msg.attach(content)
+    s = smtplib.SMTP('localhost')
+    s.sendmail(
+        CONFIG['ALERT']['from'],
+        email.split(','),
+        msg.as_string()
+        )
+    s.quit()
+
+
 @cmd.command()
 @click.option('--for-real', is_flag=True, default=False)
 @click.option('--send-mail', is_flag=True, default=False)
