@@ -12,6 +12,7 @@ from . import core
 from . import product
 
 import records
+import json
 
 
 __all__ = [
@@ -187,6 +188,7 @@ class Customer(object):
             params={'customer': self.name, 'fromdate': last_date}
             )
         infos = response['content']
+        LOGS.logger.warn('Value {}'.format(infos))
         # nill_condition = (
         #    'refnum' not in infos or
         #    infos['product'] not in [i.name for i in product.Product.all()]
@@ -225,6 +227,8 @@ class Customer(object):
         #    LOGS.logger.info("Suppression du client {}".format(self.name))
         #    return None
         # else:
+        if type(infos) is str:
+            infos = json.loads(infos)
         cdrs = sorted(
             infos.get('cdr', []),
             key=lambda x: datetime.strptime(
